# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class DiscoveryApiChainsList(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "eth": "ETH",
            "mainnet": "MAINNET",
            "0x1": "X1",
            "matic": "MATIC",
            "0x89": "X89",
            "polygon": "POLYGON",
            "bsc": "BSC",
            "binance": "BINANCE",
            "0x38": "X38",
            "fantom": "FANTOM",
            "ftm": "FTM",
            "0xfa": "XFA",
            "arbitrum": "ARBITRUM",
            "0xa4b1": "XA4B1",
            "optimism": "OPTIMISM",
            "0xa": "XA",
            "pulsechain": "PULSECHAIN",
            "0x171": "X171",
        }
    
    @schemas.classproperty
    def ETH(cls):
        return cls("eth")
    
    @schemas.classproperty
    def MAINNET(cls):
        return cls("mainnet")
    
    @schemas.classproperty
    def X1(cls):
        return cls("0x1")
    
    @schemas.classproperty
    def MATIC(cls):
        return cls("matic")
    
    @schemas.classproperty
    def X89(cls):
        return cls("0x89")
    
    @schemas.classproperty
    def POLYGON(cls):
        return cls("polygon")
    
    @schemas.classproperty
    def BSC(cls):
        return cls("bsc")
    
    @schemas.classproperty
    def BINANCE(cls):
        return cls("binance")
    
    @schemas.classproperty
    def X38(cls):
        return cls("0x38")
    
    @schemas.classproperty
    def FANTOM(cls):
        return cls("fantom")
    
    @schemas.classproperty
    def FTM(cls):
        return cls("ftm")
    
    @schemas.classproperty
    def XFA(cls):
        return cls("0xfa")
    
    @schemas.classproperty
    def ARBITRUM(cls):
        return cls("arbitrum")
    
    @schemas.classproperty
    def XA4B1(cls):
        return cls("0xa4b1")
    
    @schemas.classproperty
    def OPTIMISM(cls):
        return cls("optimism")
    
    @schemas.classproperty
    def XA(cls):
        return cls("0xa")
    
    @schemas.classproperty
    def PULSECHAIN(cls):
        return cls("pulsechain")
    
    @schemas.classproperty
    def X171(cls):
        return cls("0x171")
