# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.2
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.discovery_tokens_blue_chip.get import GetBlueChipTokens
from openapi_evm_api.paths.discovery_tokens_buying_pressure.get import GetBuyingPressureTokens
from openapi_evm_api.paths.discovery_token.get import GetDiscoveryToken
from openapi_evm_api.paths.discovery_tokens_experienced_buyers.get import GetExperiencedBuyersTokens
from openapi_evm_api.paths.discovery_tokens_rising_liquidity.get import GetRisingLiquidityTokens
from openapi_evm_api.paths.discovery_tokens_risky_bets.get import GetRiskyBetsTokens
from openapi_evm_api.paths.discovery_tokens_solid_performers.get import GetSolidPerformersTokens


class DefaultApi(
    GetBlueChipTokens,
    GetBuyingPressureTokens,
    GetDiscoveryToken,
    GetExperiencedBuyersTokens,
    GetRisingLiquidityTokens,
    GetRiskyBetsTokens,
    GetSolidPerformersTokens,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
